=======
History
=======

0.1.1 (2020-04-01)
------------------

* Remove Python 3.5 from list of supported versions
* Fix deployment issue: correct PYPI key encryption


0.1.0 (2020-04-01)
------------------

* First release on PyPI.
